==> jc-1.4.0.tar.gz: gnu/xml/xpath/XPathParser__24YyNameClass.h <==
// public final class gnu.xml.xpath.XPathParser$YyNameClass

// class file dependencies
// @dep_class e57830dabbf7d2 gnu_xml_xpath_XPathParser__24YyNameClass
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_xpath_XPathParser__24YyNameClass_H_
#define _JC_gnu_xml_xpath_XPathParser__24YyNameClass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$sub_refs	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$sub_refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$sub_nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$refs	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$object	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$object;

typedef struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$fields_struct	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$fields_struct;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$vmethods	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$vmethods;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$vtable	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$vtable;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$vtype	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$vtype;

// Class fields structure
struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$fields_struct {
	_jc_object_array	*yyName;
};
extern _jc_gnu_xml_xpath_XPathParser__24YyNameClass$fields_struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$class_fields;

// Constructors
extern void _jc_gnu_xml_xpath_XPathParser__24YyNameClass$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$object *);

// Static methods
extern void _jc_gnu_xml_xpath_XPathParser__24YyNameClass$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$vmethods {
};

// Vtable
struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$vmethods	gnu_xml_xpath_XPathParser__24YyNameClass;
};

// Vtype
struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$refs {
    _jc_gnu_xml_xpath_XPathParser__24YyNameClass$sub_refs	gnu_xml_xpath_XPathParser__24YyNameClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_XPathParser__24YyNameClass$sub_nonrefs	gnu_xml_xpath_XPathParser__24YyNameClass;
};

// Object instance structure
struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$object {
	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$vtype	*vtype;
	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_XPathParser__24YyNameClass$vtype _jc_gnu_xml_xpath_XPathParser__24YyNameClass$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_XPathParser__24YyNameClass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_XPathParser__24YyNameClass$class_object;

#endif	/* _JC_gnu_xml_xpath_XPathParser__24YyNameClass_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/xpath/XPathParser__24YyNameClass.h <==
// public final class gnu.xml.xpath.XPathParser$YyNameClass

// class file dependencies
// @dep_class e57830dabbf7d2 gnu_xml_xpath_XPathParser__24YyNameClass
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_xpath_XPathParser__24YyNameClass_H_
#define _JC_gnu_xml_xpath_XPathParser__24YyNameClass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$sub_refs	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$sub_refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$sub_nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$refs	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$nonrefs	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$object	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$object;

typedef struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$fields_struct	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$fields_struct;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$vmethods	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$vmethods;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$vtable	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$vtable;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$vtype	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$vtype;

// Class fields structure
struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$fields_struct {
	_jc_object_array	*yyName;
};
extern _jc_gnu_xml_xpath_XPathParser__24YyNameClass$fields_struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$class_fields;

// Constructors
extern void _jc_gnu_xml_xpath_XPathParser__24YyNameClass$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_xml_xpath_XPathParser__24YyNameClass$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$vmethods {
};

// Vtable
struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$vmethods	gnu_xml_xpath_XPathParser__24YyNameClass;
};

// Vtype
struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$refs {
    _jc_gnu_xml_xpath_XPathParser__24YyNameClass$sub_refs	gnu_xml_xpath_XPathParser__24YyNameClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_XPathParser__24YyNameClass$sub_nonrefs	gnu_xml_xpath_XPathParser__24YyNameClass;
};

// Object instance structure
struct _jc_gnu_xml_xpath_XPathParser__24YyNameClass$object {
	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$vtype	*vtype;
	_jc_gnu_xml_xpath_XPathParser__24YyNameClass$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_XPathParser__24YyNameClass$vtype _jc_gnu_xml_xpath_XPathParser__24YyNameClass$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_XPathParser__24YyNameClass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_XPathParser__24YyNameClass$class_object;

#endif	/* _JC_gnu_xml_xpath_XPathParser__24YyNameClass_H_ */
